pub struct UsernameGenerationSettings {
pub prefixes: Vec<String>,
pub suffixes: Vec<String>,
pub template: String,
}Fields
prefixes: Vec<String>suffixes: Vec<String>template: StringTrait Implementations
Sourceimpl Clone for UsernameGenerationSettings
impl Clone for UsernameGenerationSettings
Sourcefn clone(&self) -> UsernameGenerationSettings
fn clone(&self) -> UsernameGenerationSettings
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UsernameGenerationSettings
impl Debug for UsernameGenerationSettings
Sourceimpl<'de> Deserialize<'de> for UsernameGenerationSettings
impl<'de> Deserialize<'de> for UsernameGenerationSettings
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for UsernameGenerationSettings
impl JsonSchema for UsernameGenerationSettings
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Tsify for UsernameGenerationSettings
impl Tsify for UsernameGenerationSettings
const DECL: &'static str = "export interface UsernameGenerationSettings {\n prefixes: string[];\n suffixes: string[];\n template: string;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>